---
title: Installation
layout: page 
date: 2014-01-10
---

You can install Urubu using pip: 

```
pip install urubu
```

If pip is not yet available on your system, follow the [pip installation
instructions][pip_install].

[pip_install]: http://www.pip-installer.org/en/latest/installing.html

You may want to install Urubu in an isolated environment using [virtualenv].

Urubu depends on a number of libraries that will automatically be installed if
not yet available: [python_markdown], [pyyaml], [pygments] and [jinja2].

